#[non_exhaustive]pub enum FrameError {
NonFiniteInput,
NotUnitLength,
NotPerpendicular,
Degenerate,
NotRightHanded,
}Expand description
Why a basis could not form an in-plane frame.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonFiniteInput
An origin or axis component was NaN or infinite.
NotUnitLength
An axis was not unit length within the angular tolerance.
NotPerpendicular
The two axes were not perpendicular within the angular tolerance.
Degenerate
The axes were parallel, so they span a line rather than a plane.
NotRightHanded
The basis is mirrored: orthonormal, but left-handed.